<?php
/**
 * @version   1.1.0
 * @date      February 11, 2013
 * @author    Randy Carey  http://iCueProject.com
 * @copyright Copyright (C) 2013 Randy Carey, iCue Project
 * @license   http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 only
 */

// no direct access
defined('_JEXEC') or die('Restricted index access');

class plgSystemAddCSSFiles extends JPlugin {
    private $_app;
    private $_template_name;

	public function onBeforeCompileHead(){
	   	$this->_app =& JFactory::getApplication();

        if ($this->_app->isSite()) {
            // app is SITE
    		$global_file_name= $this->params->get('sitecss','');
            $appendage=strpos($global_file_name,'.') ? '' : '.css'; // create appendage only if no extension - this allows user to declare filename with .php extensions
			if($global_file_name){
	    		$this->addCssFile(false, $global_file_name, $appendage);
			}
            switch($this->params->get('site_com_level')){
                case '1': // always include
                    $this->addComponentSpecificFile(false);
                    break;
                case '2': // include only component-specific
                    $this->addComponentSpecificFile(false,true);
                    break;
                case '0': // never include component-specific
                default:
                    break;

            }
        }
	   	else { // app is ADMIN
    		$global_file_name = $this->params->get('admincss','');
            $appendage=strpos($global_file_name,'.') ? '' : '.css'; // create appendage only if no extension - this allows user to declare filename with .php extensions
			if($global_file_name){
	    		$this->addCssFile(true, $global_file_name, $appendage);
			}
            switch($this->params->get('admin_com_level')){
                case '1': // always include
                    $this->addComponentSpecificFile(true);
                    break;
                case '2': // include only component-specific
                    $this->addComponentSpecificFile(true, true);
                    break;
                case '0': // never include component-specific
                default:
                    break;
            }
        }
    }

    /**
     * @param bool $isAdmin
     * @param bool $uses_levels
     */
    private function addComponentSpecificFile($isAdmin = false, $uses_levels = false){
        $option = $this->_app->input->get('option');
        if($uses_levels && !$this->isCurrentComponentSpecified($isAdmin, $option)){
            return;
        }
        $this->addCssFile($isAdmin, $option, '.css');
    }

    /**
     * @param $isAdmin
     * @param $component_name
     * @return bool
     */
    private function isCurrentComponentSpecified($isAdmin, $component_name)
    {
        $list = $isAdmin ? $this->params->get('admin_coms') : $this->params->get('site_coms');
        $packed_list = str_replace(' ', '', $list);
        $com_list = explode(',', $packed_list);
        if (!in_array($component_name, $com_list)) {
            return false;
        }
        return true;
    }

    /**
     * @param $isAdmin
     * @param $file_name
     * @param $appendage    If needed, is the text for a file extension to append to file name
     */
    private function addCssFile($isAdmin, $file_name, $appendage='')
    {
        $admin_dir = $isAdmin ? '/administrator' : '';
        JFactory::getDocument()->addStyleSheet(JUri::root(true).$admin_dir.'/templates/' . $this->getTemplateName($isAdmin) . '/css/' . $file_name.$appendage,"text/css");
    }

    /**
     * @return string   The name of the template directory to use
     */
    private function getTemplateName($isAdmin){
        if(!$this->_template_name){
            $tmpl_path_param_name = $isAdmin ? 'admin_template_path' : 'site_template_path';
            $this->_template_name = ($this->params->get($tmpl_path_param_name)=='1') ? $this->_app->getTemplate() : 'system';
        }
        return $this->_template_name;
    }

}